package com.jjt.biz.controller;

import java.util.List;
import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.jjt.common.annotation.Log;
import com.jjt.common.core.controller.BaseController;
import com.jjt.common.core.domain.AjaxResult;
import com.jjt.common.enums.BusinessType;
import com.jjt.biz.domain.BizObjData;
import com.jjt.biz.service.IBizObjDataService;
import com.jjt.common.utils.poi.ExcelUtil;
import com.jjt.common.core.page.TableDataInfo;

/**
 * 业务对象数据接口Controller
 *
 * @author jjt
 * @date 2024-08-09
 */
@Api(tags="业务对象数据接口")
@RestController
@RequestMapping("/obj/data")
public class BizObjDataController extends BaseController
{
    @Resource
    private IBizObjDataService bizObjDataService;

    /**
     * 查询业务对象数据接口列表
     */
    @ApiOperation("查询业务对象数据接口列表")
    @PreAuthorize("@ss.hasPermi('obj:data:list')")
    @GetMapping("/list")
    public TableDataInfo list(BizObjData bizObjData)
    {
        startPage();
        List<BizObjData> list = bizObjDataService.selectBizObjDataList(bizObjData);
        return getDataTable(list);
    }

    /**
     * 导出业务对象数据接口列表
     */
    @ApiOperation("导出业务对象数据接口列表")
    @PreAuthorize("@ss.hasPermi('obj:data:export')")
    @Log(title = "业务对象数据接口", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, BizObjData bizObjData)
    {
        List<BizObjData> list = bizObjDataService.selectBizObjDataList(bizObjData);
        ExcelUtil<BizObjData> util = new ExcelUtil<BizObjData>(BizObjData.class);
        util.exportExcel(response, list, "业务对象数据接口数据");
    }

    /**
     * 获取业务对象数据接口详细信息
     */
    @ApiOperation("获取业务对象数据接口详细信息")
    @PreAuthorize("@ss.hasPermi('obj:data:query')")
    @GetMapping(value = "/{dataId}")
    public AjaxResult getInfo(@PathVariable("dataId") Long dataId)
    {
        return success(bizObjDataService.selectBizObjDataByDataId(dataId));
    }

    /**
     * 新增业务对象数据接口
     */
    @ApiOperation("新增业务对象数据接口")
    @PreAuthorize("@ss.hasPermi('obj:data:add')")
    @Log(title = "业务对象数据接口", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody BizObjData bizObjData)
    {
        return toAjax(bizObjDataService.insertBizObjData(bizObjData));
    }

    /**
     * 修改业务对象数据接口
     */
    @ApiOperation("修改业务对象数据接口")
    @PreAuthorize("@ss.hasPermi('obj:data:edit')")
    @Log(title = "业务对象数据接口", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody BizObjData bizObjData)
    {
        return toAjax(bizObjDataService.updateBizObjData(bizObjData));
    }

    /**
     * 删除业务对象数据接口
     */
    @ApiOperation("删除业务对象数据接口")
    @PreAuthorize("@ss.hasPermi('obj:data:remove')")
    @Log(title = "业务对象数据接口", businessType = BusinessType.DELETE)
	@DeleteMapping("/{dataIds}")
    public AjaxResult remove(@PathVariable Long[] dataIds)
    {
        return toAjax(bizObjDataService.deleteBizObjDataByDataIds(dataIds));
    }
}
